@@ -32,11 +32,6 @@ import javax.jmdns.impl.ServiceInfoImpl;
  */
 public abstract class ServiceInfo implements Cloneable {
 
-    /**
-     * This is the no value text byte. According top the specification it is one byte with 0 value.
-     */
-    public static final byte[] NO_VALUE = new byte[0];
-
     /**
      * Fields for the fully qualified map.
      */
